<?php declare(strict_types=1);

namespace App\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Camera
 */
#[ORM\Table(name: 'film', schema: 'camera')]
#[ORM\Entity]
class Film
{
	/**
	 * @var integer
	 */
	#[ORM\Id]
	#[ORM\Column(name: 'id', type: 'integer', nullable: false)]
	#[ORM\GeneratedValue(strategy: 'IDENTITY')]
	private $id;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'brand', type: 'string', nullable: false)]
	private string $brand;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'product_line', type: 'string', nullable: true)]
	private ?string $productLine;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'film_name', type: 'string', nullable: false)]
	private string $filmName;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'film_alias', type: 'string', nullable: true)]
	private ?string $filmAlias;
	/**
	 * @var int
	 */
	#[ORM\Column(name: 'film_speed_asa', type: 'integer', nullable: false)]
	private int $filmSpeedAsa;
	/**
	 * @var int
	 */
	#[ORM\Column(name: 'film_speed_din', type: 'integer', nullable: false)]
	private int $filmSpeedDin;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'film_format', type: 'string', nullable: false)]
	private string $filmFormat;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'film_base', type: 'string', nullable: false, options: ['default' => 'Cellulose Triacetate'])]
	private string $filmBase = 'Cellulose Triacetate';
	/**
	 * @var int
	 */
	#[ORM\Column(name: 'unused_rolls', type: 'integer', nullable: false, options: ['default' => 0])]
	private int $unusedRolls = 0;
	/**
	 * @var int
	 */
	#[ORM\Column(name: 'rolls_in_camera', type: 'integer', nullable: false, options: ['default' => 0])]
	private int $rollsInCamera = 0;
	/**
	 * @var int
	 */
	#[ORM\Column(name: 'developed_rolls', type: 'integer', nullable: false, options: ['default' => 0])]
	private int $developedRolls = 0;
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'chemistry', type: 'string', nullable: false, options: ['default' => 'C-41'])]
	private string $chemistry = 'C-41';
	/**
	 * @var string
	 */
	#[ORM\Column(name: 'notes', type: 'text', nullable: true)]
	private ?string $notes;
	/**
	 * @return int
	 */
	public function getId(): int
	{
		return $this->id;
	}
	/**
	 * @return string
	 */
	public function getBrand(): ?string
	{
		return $this->brand;
	}
	/**
	 * @param string $brand
	 * @return self
	 */
	public function setBrand(string $brand): self
	{
		$this->brand = $brand;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getProductLine(): ?string
	{
		return $this->productLine;
	}
	/**
	 * @param string $productLine
	 * @return self
	 */
	public function setProductLine(?string $productLine): self
	{
		$this->productLine = $productLine;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getFilmName(): ?string
	{
		return $this->filmName;
	}
	/**
	 * @param string $filmName
	 * @return self
	 */
	public function setFilmName(string $filmName): self
	{
		$this->filmName = $filmName;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getFilmAlias(): ?string
	{
		return $this->filmAlias;
	}
	/**
	 * @param string $filmAlias
	 * @return self
	 */
	public function setFilmAlias(string $filmAlias): self
	{
		$this->filmAlias = $filmAlias;
		return $this;
	}
	/**
	 * @return int
	 */
	public function getFilmSpeedAsa(): ?int
	{
		return $this->filmSpeedAsa;
	}
	/**
	 * @param int $filmSpeedAsa
	 * @return self
	 */
	public function setFilmSpeedAsa(int $filmSpeedAsa): self
	{
		$this->filmSpeedAsa = $filmSpeedAsa;
		return $this;
	}
	/**
	 * @return int
	 */
	public function getFilmSpeedDin(): ?int
	{
		return $this->filmSpeedDin;
	}
	/**
	 * @param int $filmSpeedDin
	 * @return self
	 */
	public function setFilmSpeedDin(int $filmSpeedDin): self
	{
		$this->filmSpeedDin = $filmSpeedDin;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getFilmFormat(): ?string
	{
		return $this->filmFormat;
	}
	/**
	 * @param string $filmFormat
	 * @return self
	 */
	public function setFilmFormat(string $filmFormat): self
	{
		$this->filmFormat = $filmFormat;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getFilmBase(): ?string
	{
		return $this->filmBase;
	}
	/**
	 * @param string $filmBase
	 * @return self
	 */
	public function setFilmBase(string $filmBase): self
	{
		$this->filmBase = $filmBase;
		return $this;
	}
	/**
	 * @return int
	 */
	public function getUnusedRolls(): ?int
	{
		return $this->unusedRolls;
	}
	/**
	 * @param int $unusedRolls
	 * @return self
	 */
	public function setUnusedRolls(int $unusedRolls): self
	{
		$this->unusedRolls = $unusedRolls;
		return $this;
	}
	/**
	 * @return int
	 */
	public function getRollsInCamera(): ?int
	{
		return $this->rollsInCamera;
	}
	/**
	 * @param int $rollsInCamera
	 * @return self
	 */
	public function setRollsInCamera(int $rollsInCamera): self
	{
		$this->rollsInCamera = $rollsInCamera;
		return $this;
	}
	/**
	 * @return int
	 */
	public function getDevelopedRolls(): ?int
	{
		return $this->developedRolls;
	}
	/**
	 * @param int $developedRolls
	 * @return self
	 */
	public function setDevelopedRolls(int $developedRolls): self
	{
		$this->developedRolls = $developedRolls;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getChemistry(): ?string
	{
		return $this->chemistry;
	}
	/**
	 * @param string $chemistry
	 * @return self
	 */
	public function setChemistry(string $chemistry): self
	{
		$this->chemistry = $chemistry;
		return $this;
	}
	/**
	 * @return string
	 */
	public function getNotes(): ?string
	{
		return $this->notes;
	}
	/**
	 * @param string $notes
	 * @return self
	 */
	public function setNotes(string $notes): self
	{
		$this->notes = $notes;
		return $this;
	}
}
