<?php declare(strict_types=1);

namespace App\Entity;

trait LensTrait
{
	use PurchasePriceTrait;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="brand", type="string", length=64, nullable=true)
	 */
	private ?string $brand;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="coatings", type="string", length=64, nullable=true)
	 */
	private ?string $coatings;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="product_line", type="string", length=64, nullable=true)
	 */
	private ?string $productLine;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="model", type="string", length=64, nullable=true)
	 */
	private ?string $model;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="min_f_stop", type="string", length=10, nullable=true)
	 */
	private ?string $minFStop;

	/**
	 * @var float
	 *
	 * @ORM\Column(name="max_f_stop", type="float", precision=10, scale=0, nullable=true)
	 */
	private ?float $maxFStop;

	/**
	 * @var integer
	 *
	 * @ORM\Column(name="min_focal_length", type="integer", nullable=true)
	 */
	private ?int $minFocalLength;

	/**
	 * @var integer
	 *
	 * @ORM\Column(name="max_focal_length", type="integer", nullable=true)
	 */
	private ?int $maxFocalLength;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="serial", type="string", length=10, nullable=true)
	 */
	private ?string $serial;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="purchase_price", type="money", nullable=true)
	 */
	private ?string $purchasePrice;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="notes", type="text", nullable=true)
	 */
	private ?string $notes;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="image_size", type="string", nullable=false, options={"default"="35mm"})
	 */
	private string $imageSize = '35mm';

	/**
	 * @var string
	 *
	 * @ORM\Column(name="mount", type="string", length=40, nullable=true)
	 */
	private ?string $mount;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="front_filter_size", type="decimal", precision=10, scale=0, nullable=true)
	 */
	private ?string $frontFilterSize;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="rear_filter_size", type="decimal", precision=10, scale=0, nullable=true)
	 */
	private? string $rearFilterSize;

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="is_teleconverter", type="boolean", nullable=false)
	 */
	private bool $isTeleconverter = false;

	/**
	 * @var integer
	 *
	 * @ORM\Column(name="design_elements", type="smallint", nullable=true)
	 */
	private ?int $designElements;

	/**
	 * @var integer
	 *
	 * @ORM\Column(name="design_groups", type="smallint", nullable=true)
	 */
	private ?int $designGroups;

	/**
	 * @var integer
	 *
	 * @ORM\Column(name="aperture_blades", type="smallint", nullable=true)
	 */
	private ?int $apertureBlades;


	/**
	 * Get id
	 *
	 * @return integer
	 */
	public function getId(): int
	{
		return $this->id;
	}

	/**
	 * Set brand
	 *
	 * @param string $brand
	 *
	 * @return self
	 */
	public function setBrand($brand): self
	{
		$this->brand = $brand;

		return $this;
	}

	/**
	 * Get brand
	 *
	 * @return string
	 */
	public function getBrand()
	{
		return $this->brand;
	}

	/**
	 * Set coatings
	 *
	 * @param string $coatings
	 *
	 * @return self
	 */
	public function setCoatings($coatings): self
	{
		$this->coatings = $coatings;

		return $this;
	}

	/**
	 * Get coatings
	 *
	 * @return string
	 */
	public function getCoatings()
	{
		return $this->coatings;
	}

	/**
	 * Set productLine
	 *
	 * @param string $productLine
	 *
	 * @return self
	 */
	public function setProductLine($productLine): self
	{
		$this->productLine = $productLine;

		return $this;
	}

	/**
	 * Get productLine
	 *
	 * @return string
	 */
	public function getProductLine()
	{
		return $this->productLine;
	}

	/**
	 * Set model
	 *
	 * @param string $model
	 *
	 * @return self
	 */
	public function setModel($model): self
	{
		$this->model = $model;

		return $this;
	}

	/**
	 * Get model
	 *
	 * @return string
	 */
	public function getModel()
	{
		return $this->model;
	}

	/**
	 * Set minFStop
	 *
	 * @param string $minFStop
	 *
	 * @return self
	 */
	public function setMinFStop($minFStop): self
	{
		$this->minFStop = $minFStop;

		return $this;
	}

	/**
	 * Get minFStop
	 *
	 * @return string
	 */
	public function getMinFStop()
	{
		return $this->minFStop;
	}

	/**
	 * Set maxFStop
	 *
	 * @param float $maxFStop
	 *
	 * @return self
	 */
	public function setMaxFStop($maxFStop): self
	{
		$this->maxFStop = $maxFStop;

		return $this;
	}

	/**
	 * Get maxFStop
	 *
	 * @return float
	 */
	public function getMaxFStop()
	{
		return $this->maxFStop;
	}

	/**
	 * Set minFocalLength
	 *
	 * @param integer $minFocalLength
	 *
	 * @return self
	 */
	public function setMinFocalLength($minFocalLength): self
	{
		$this->minFocalLength = $minFocalLength;

		return $this;
	}

	/**
	 * Get minFocalLength
	 *
	 * @return integer
	 */
	public function getMinFocalLength()
	{
		return $this->minFocalLength;
	}

	/**
	 * Set maxFocalLength
	 *
	 * @param integer $maxFocalLength
	 *
	 * @return self
	 */
	public function setMaxFocalLength($maxFocalLength): self
	{
		$this->maxFocalLength = $maxFocalLength;

		return $this;
	}

	/**
	 * Get maxFocalLength
	 *
	 * @return integer
	 */
	public function getMaxFocalLength()
	{
		return $this->maxFocalLength;
	}

	/**
	 * Set serial
	 *
	 * @param string $serial
	 *
	 * @return self
	 */
	public function setSerial($serial): self
	{
		$this->serial = $serial;

		return $this;
	}

	/**
	 * Get serial
	 *
	 * @return string
	 */
	public function getSerial(): string
	{
		return $this->serial ?? '';
	}

	/**
	 * Set notes
	 *
	 * @param string $notes
	 *
	 * @return self
	 */
	public function setNotes(?string $notes): self
	{
		$this->notes = $notes;

		return $this;
	}

	/**
	 * Get notes
	 *
	 * @return string
	 */
	public function getNotes(): string
	{
		return $this->notes ?? '';
	}

	/**
	 * Get image size
	 *
	 * @return string
	 */
	public function getImageSize(): string
	{
		return $this->imageSize;
	}

	/**
	 * Set image size
	 *
	 * @param string $imageSize
	 * @return self
	 */
	public function setImageSize(string $imageSize): self
	{
		$this->imageSize = $imageSize;
		return $this;
	}

	/**
	 * Set mount
	 *
	 * @param string $mount
	 *
	 * @return self
	 */
	public function setMount($mount): self
	{
		$this->mount = $mount;

		return $this;
	}

	/**
	 * Get mount
	 *
	 * @return string
	 */
	public function getMount()
	{
		return $this->mount;
	}

	/**
	 * Set received
	 *
	 * @param boolean $received
	 *
	 * @return self
	 */
	public function setReceived($received): self
	{
		$this->received = $received;

		return $this;
	}

	/**
	 * Get received
	 *
	 * @return boolean
	 */
	public function getReceived()
	{
		return $this->received;
	}

	/**
	 * Set formerlyOwned
	 *
	 * @param boolean $formerlyOwned
	 *
	 * @return self
	 */
	public function setFormerlyOwned($formerlyOwned): self
	{
		$this->formerlyOwned = $formerlyOwned;

		return $this;
	}

	/**
	 * Get formerlyOwned
	 *
	 * @return boolean
	 */
	public function getFormerlyOwned()
	{
		return $this->formerlyOwned;
	}

	/**
	 * Set frontFilterSize
	 *
	 * @param string $frontFilterSize
	 *
	 * @return self
	 */
	public function setFrontFilterSize($frontFilterSize): self
	{
		$this->frontFilterSize = $frontFilterSize;

		return $this;
	}

	/**
	 * Get frontFilterSize
	 *
	 * @return string
	 */
	public function getFrontFilterSize()
	{
		return $this->frontFilterSize;
	}

	/**
	 * Set rearFilterSize
	 *
	 * @param string $rearFilterSize
	 *
	 * @return self
	 */
	public function setRearFilterSize($rearFilterSize): self
	{
		$this->rearFilterSize = $rearFilterSize;

		return $this;
	}

	/**
	 * Get rearFilterSize
	 *
	 * @return string
	 */
	public function getRearFilterSize()
	{
		return $this->rearFilterSize;
	}

	/**
	 * Set isTeleconverter
	 *
	 * @param boolean $isTeleconverter
	 *
	 * @return self
	 */
	public function setIsTeleconverter($isTeleconverter): self
	{
		$this->isTeleconverter = $isTeleconverter;

		return $this;
	}

	/**
	 * Get isTeleconverter
	 *
	 * @return boolean
	 */
	public function getIsTeleconverter()
	{
		return $this->isTeleconverter;
	}

	/**
	 * Set designElements
	 *
	 * @param integer $designElements
	 *
	 * @return self
	 */
	public function setDesignElements($designElements): self
	{
		$this->designElements = $designElements;

		return $this;
	}

	/**
	 * Get designElements
	 *
	 * @return integer
	 */
	public function getDesignElements()
	{
		return $this->designElements;
	}

	/**
	 * Set designGroups
	 *
	 * @param integer $designGroups
	 *
	 * @return self
	 */
	public function setDesignGroups($designGroups): self
	{
		$this->designGroups = $designGroups;

		return $this;
	}

	/**
	 * Get designGroups
	 *
	 * @return integer
	 */
	public function getDesignGroups()
	{
		return $this->designGroups;
	}

	/**
	 * Set apertureBlades
	 *
	 * @param integer $apertureBlades
	 *
	 * @return self
	 */
	public function setApertureBlades($apertureBlades): self
	{
		$this->apertureBlades = $apertureBlades;

		return $this;
	}

	/**
	 * Get apertureBlades
	 *
	 * @return integer
	 */
	public function getApertureBlades(): ?int
	{
		return $this->apertureBlades;
	}
}
